@@ -1,4 +1,4 @@
-from rubpy import Client, Methods
+from shadapi import Client, Methods
 
 app = Client(auth='your_auth')
 group_guid = 'your_group_guid'
@@ -26,4 +26,4 @@ async def Deleter(bot: Methods) -> None:
                 await bot.banGroupMember(
                     group_guid=group_guid, member_guid=member_guid, action='Unset')
 
-app.run(Deleter)
\ No newline at end of file
+app.run(Deleter)
